// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import type { Browserbase } from './index';

export class APIResource {
  protected _client: Browserbase;

  constructor(client: Browserbase) {
    this._client = client;
  }
}
