"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const registry_1 = require("../_shims/registry.js");
const web_runtime_1 = require("../_shims/web-runtime.js");
(0, registry_1.setShims)((0, web_runtime_1.getRuntime)({ manuallyImported: true }));
//# sourceMappingURL=web.js.map