// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
export class Recording extends APIResource {
    /**
     * Session Recording
     */
    retrieve(id, options) {
        return this._client.get(`/v1/sessions/${id}/recording`, options);
    }
}
//# sourceMappingURL=recording.mjs.map