// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
export class Logs extends APIResource {
    /**
     * Session Logs
     */
    list(id, options) {
        return this._client.get(`/v1/sessions/${id}/logs`, options);
    }
}
//# sourceMappingURL=logs.mjs.map