import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
import { type Response } from "../../_shims/index.js";
export declare class Downloads extends APIResource {
    /**
     * Session Downloads
     */
    list(id: string, options?: Core.RequestOptions): Core.APIPromise<Response>;
}
//# sourceMappingURL=downloads.d.ts.map