"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const registry_1 = require("../_shims/registry.js");
const node_runtime_1 = require("../_shims/node-runtime.js");
(0, registry_1.setShims)((0, node_runtime_1.getRuntime)());
//# sourceMappingURL=node.js.map