"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logs = void 0;
const resource_1 = require("../../resource.js");
class Logs extends resource_1.APIResource {
    /**
     * Session Logs
     */
    list(id, options) {
        return this._client.get(`/v1/sessions/${id}/logs`, options);
    }
}
exports.Logs = Logs;
//# sourceMappingURL=logs.js.map